
Dependencies
===============

`cubicweb-squareui`
-------------------

The `cubicweb-bootstrap` ca be used without `cubicweb-squareui` if you
have your own redefinition of the `basetemplates.TheMainTemplate` class
what `cubicweb-squareui` basically does. The `cubicweb-squareui` cube
is thus not mandatory, but suggested.

**Important**

If you use `cubicweb-bootstrap` >= 0.5.0 and
`cubicweb-squareui`, be sure than the `cubicweb-squareui` version is
at least 0.3.0

